Module metadata

Module metadata 

Defines an API for reading the metadata associated with the diagnostic metrics.

Structs

Metadata
Metadata defines the metadata associated with the diagnostic metrics.